![HorizonGRound logo](
https://raw.githubusercontent.com/MikeSWang/HorizonGRound/v0.1/docs/source/_static/HorizonGRound.png)

[![arXiv eprint](
https://img.shields.io/badge/arXiv-2007.01802-important
)](https://arxiv.org/abs/2007.01802)
[![GitHub release](
https://img.shields.io/badge/release-v0.1-blue
)](https://github.com/MikeSWang/HorizonGRound/releases/v0.1)
[![Documentation status](
https://readthedocs.org/projects/horizonground/badge/?version=stable
)](https://horizonground.readthedocs.io/en/stable)
[![Build status](
https://travis-ci.com/MikeSWang/HorizonGRound.svg?branch=v0.1
)](https://travis-ci.com/MikeSWang/HorizonGRound)
[![Code Coverage](
https://img.shields.io/codecov/c/github/MikeSWang/HorizonGRound
)](https://codecov.io/gh/MikeSWang/HorizonGRound)
[![Licence](
https://img.shields.io/badge/licence-GPLv3-informational
)](https://github.com/mikeswang/HorizonGRound/tree/v0.1/LICENCE)


# Relativistic Effects in Ultra-Large-Scale Clustering

<span style="font-variant: small-caps">HorizonGRound</span> is a Python
package that offers tools for forward modelling of general relativistic
effects from the tracer luminosity function as well as comparing relativistic
corrections with the local primordial non-Gaussianity signature in
ultra-large-scale clustering statistics.


## Installation

To install, enter in bash:

```bash
pip install HorizonGRound
```


## Documentation

Quick recipes and API documentation can be found at
[mikeswang.github.io/HorizonGRound](
https://horizonground.readthedocs.io/en/stable).


## Attribution

If you would like to acknowledge this work, please cite
`Wang, Beutler & Bacon (2020) <https://arxiv.org/abs/2007.01802>`. You
may use the following BibTeX record.

    @article{Wang_2020a,
        author = {Wang, M.~S. and Beutler, F. and Bacon, D.},
        title = {%
            Impact of relativistic effects on the primordial {non-Gaussianity} %
            signature in the large-scale clustering of quasars%
        },
        year = {2020},
        archivePrefix = {arXiv},
        primaryClass = {astro-ph.CO},
        eprint = {2007.01802},
    }


## Licence

Copyright 2020, M S Wang

<span style="font-variant: small-caps">HorizonGRound</span> is made freely
available under the [GPL v3.0](https://www.gnu.org/licenses/gpl-3.0.en.html)
licence.
